import { Network, Platform } from "@wormhole-foundation/sdk-base";
import { ChainsConfig } from "@wormhole-foundation/sdk-definitions";
export declare const DEFAULT_TASK_TIMEOUT: number;
export type WormholeConfig<N extends Network = Network, P extends Platform = Platform> = {
    api: string;
    circleAPI: string;
    chains: ChainsConfig<N, P>;
};
type RecursivePartial<T> = {
    [P in keyof T]?: T[P] extends (infer U)[] ? RecursivePartial<U>[] : T[P] extends object | undefined ? RecursivePartial<T[P]> : T[P];
};
export type ConfigOverrides = RecursivePartial<WormholeConfig>;
export declare const CONFIG: {
    readonly Mainnet: {
        readonly api: "https://api.wormholescan.io";
        readonly circleAPI: "https://iris-api.circle.com/v1/attestations";
        readonly chains: ChainsConfig<"Mainnet", "Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Evm" | "Cosmwasm">;
    };
    readonly Testnet: {
        readonly api: "https://api.testnet.wormholescan.io";
        readonly circleAPI: "https://iris-api-sandbox.circle.com/v1/attestations";
        readonly chains: ChainsConfig<"Testnet", "Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Evm" | "Cosmwasm">;
    };
    readonly Devnet: {
        readonly api: "http://guardian:7071";
        readonly circleAPI: "";
        readonly chains: ChainsConfig<"Devnet", "Solana" | "Algorand" | "Near" | "Sui" | "Aptos" | "Btc" | "Evm" | "Cosmwasm">;
    };
};
export declare function networkPlatformConfigs<N extends Network, P extends Platform>(network: N, platform: P): ChainsConfig<N, P>;
export declare function applyOverrides<N extends Network>(network: N, overrides?: ConfigOverrides): WormholeConfig;
export declare const DEFAULT_NETWORK: Network;
export {};
//# sourceMappingURL=config.d.ts.map