import { tokens } from "@wormhole-foundation/sdk-base";
import { canonicalAddress, isNative, } from "@wormhole-foundation/sdk-definitions";
import { Wormhole } from "../wormhole";
export function uniqueTokens(tokens) {
    if (tokens.length === 0)
        return [];
    // take the first chain, all should be equal
    const { chain } = tokens[0];
    if (!tokens.every((t) => t.chain === chain))
        throw new Error("Not every chain is equal");
    return Array.from(new Set(tokens.map((t) => canonicalAddress(t)))).map((a) => Wormhole.tokenId(chain, a));
}
export function tokenAddresses(tokens) {
    return tokens.map((t) => canonicalAddress(t));
}
export async function getTokenDetails(chain, token) {
    const address = canonicalAddress(token);
    const details = chain.config.tokenMap
        ? tokens.filters.byAddress(chain.config.tokenMap, address)
        : undefined;
    const symbol = details ? details.symbol : undefined;
    const wrapped = isNative(token.address) ? await chain.getNativeWrappedTokenId() : undefined;
    const decimals = Number(await chain.getDecimals(token.address));
    return {
        id: token,
        decimals,
        wrapped,
        symbol,
    };
}
//# sourceMappingURL=token.js.map